@@ -21,7 +21,7 @@ from vivarium.library.dict_utils import deep_merge, deep_merge_check, MULTI_UPDA
 from vivarium.library.topology import without, dict_to_paths
 from vivarium.core.types import Processes, Topology, State, Steps, Flow
 
-_EMPTY_UPDATES = None, None, None, None, None
+_EMPTY_UPDATES = None, None, None, None, None, None
 
 
 def generate_state(
@@ -1227,8 +1227,8 @@ class Store:
         for daughter, daughter_state in \
                 zip(daughters, daughter_states):
             # use initial state as default, merge in divided values
-            initial_state = deep_merge(
-                initial_state,
+            merged_initial_state = deep_merge(
+                copy.deepcopy(initial_state),
                 daughter_state)
 
             daughter_key = daughter['key']
@@ -1236,7 +1236,7 @@ class Store:
 
             # get the daughter processes
             if 'processes' in daughter or 'steps' in daughter:
-                processes = copy.deepcopy(daughter['processes'])
+                processes = daughter['processes']
                 deep_merge_check(processes, daughter.get('steps', {}))
             else:
                 # if no processes provided, copy the mother's processes
@@ -1268,7 +1268,7 @@ class Store:
                 {},
                 flow,
                 topology,
-                initial_state)
+                merged_initial_state)
 
             root = here + daughter_path
             process_paths = dict_to_paths(root, processes)
@@ -1285,7 +1285,7 @@ class Store:
             self.apply_subschema_path(daughter_path)
             target = self.get_path(daughter_path)
             target.apply_defaults()
-            target.set_value(initial_state)
+            target.set_value(merged_initial_state)
 
 
         self.delete_path(mother_path)
@@ -1384,6 +1384,7 @@ class Store:
               The result of the reduction will be assigned to this point
               in the tree.
         """
+        view_expire = False
 
         if isinstance(update, dict) and MULTI_UPDATE_KEY in update:
             # apply multiple updates to same node
@@ -1431,11 +1432,11 @@ class Store:
                         insert_processes, insert_steps, insert_flows,
                         insert_topology
                     ) = self.insert(generate)
-                    self.build_topology_views()
                     process_updates.extend(insert_processes)
                     step_updates.extend(insert_steps)
                     flow_updates.extend(insert_flows)
                     topology_updates.extend(insert_topology)
+                    view_expire = True
 
             divide = update.pop('_divide', None)
             if divide is not None:
@@ -1443,12 +1444,12 @@ class Store:
                     divide_processes, divide_steps, divide_flow,
                     divide_topology, divide_deletions
                 ) = self.divide(divide)
-                self.build_topology_views()
                 process_updates.extend(divide_processes)
                 step_updates.extend(divide_steps)
                 flow_updates.extend(divide_flow)
                 topology_updates.extend(divide_topology)
                 deletions.extend(divide_deletions)
+                view_expire = True
 
             delete_keys = update.pop('_delete', None)
 
@@ -1457,7 +1458,7 @@ class Store:
                     inner = self.inner[key]
                     (
                         inner_topology, inner_processes, inner_steps,
-                        inner_flows, inner_deletions
+                        inner_flows, inner_deletions, inner_view_expire
                     ) = inner.apply_update(value, state)
 
                     if inner_topology:
@@ -1470,6 +1471,8 @@ class Store:
                         flow_updates.extend(inner_flows)
                     if inner_deletions:
                         deletions.extend(inner_deletions)
+                    if inner_view_expire:
+                        view_expire = inner_view_expire
 
             if delete_keys is not None:
                 # delete a list of paths
@@ -1480,7 +1483,7 @@ class Store:
 
             return (
                 topology_updates, process_updates, step_updates,
-                flow_updates, deletions)
+                flow_updates, deletions, view_expire)
 
         # Leaf update: this node has no inner
 
